@@ -1184,13 +1184,6 @@ static DBusHandlerResult xfpm_driver_signal_filter
         return DBUS_HANDLER_RESULT_HANDLED;
     }    
     
-    if ( dbus_message_is_signal(message,"xfpm.power.manager","Running" ) )
-    {
-        XFPM_DEBUG("message running received\n");
-        xfpm_driver_send_reply(connection,message);
-        return DBUS_HANDLER_RESULT_HANDLED;
-    }    
-    
     return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
 }
 
@@ -1246,6 +1239,8 @@ xfpm_driver_monitor (XfpmDriver *drv)
         
     }
     
+    xfpm_dbus_register_name(priv->conn);
+    
     xfpm_driver_load_config(drv);    
     _get_system_form_factor(priv);
     
@@ -1254,8 +1249,12 @@ xfpm_driver_monitor (XfpmDriver *drv)
     xfpm_driver_load_all(drv);
     
     g_main_loop_run(priv->loop);
-    
+   
+    xfpm_dbus_release_name(priv->conn);
+      
     dbus_connection_remove_filter(priv->conn,xfpm_driver_signal_filter,NULL);
+    
+       
     xfconf_shutdown();
     
     return TRUE;
