@@ -58,7 +58,7 @@ static gboolean config  = FALSE;
 static gboolean version = FALSE;
 
 static GOptionEntry option_entries[] = {
-	{ "run", 'r', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE, &run, N_("Start xfce power manager"), NULL },
+    { "run",'r', G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_NONE,&run,NULL,NULL },
 	{ "customize", 'c', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE, &config, N_("Show the configuration dialog"), NULL },
 	{ "quit", 'q', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE, &quit, N_("Quit any running xfce power manager"), NULL },
     { "socket-id", 's', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_INT, &socket_id, N_("Settings manager socket"), N_("SOCKET ID") },
@@ -69,7 +69,6 @@ static GOptionEntry option_entries[] = {
 static void
 show_version()
 {
-    setlocale(LC_ALL,"");
 	g_print (_("\n"
              "Xfce Power Manager %s\n\n"
              "Part of the Xfce Goodies Project\n"
@@ -118,7 +117,7 @@ autostart()
     g_key_file_set_string(key,"Desktop Entry","Type","Application");    
     g_key_file_set_string(key,"Desktop Entry","Name","Xfce4 Power Manager"); 
     g_key_file_set_string(key,"Desktop Entry","Icon","gpm-ac-adapter"); 
-    g_key_file_set_string(key,"Desktop Entry","Exec","xfce4-power-manager -r"); 
+    g_key_file_set_string(key,"Desktop Entry","Exec","xfce4-power-manager"); 
     g_key_file_set_boolean(key,"Desktop Entry","StartupNotify",FALSE); 
     g_key_file_set_boolean(key,"Desktop Entry","Terminal",FALSE); 
     g_key_file_set_boolean(key,"Desktop Entry","Hidden",FALSE); 
@@ -152,7 +151,7 @@ autostart()
 int main(int argc,char **argv) 
 {
     xfce_textdomain (GETTEXT_PACKAGE, LOCALEDIR, "UTF-8");
-    
+
    	GError *error = NULL;
 
     if(!gtk_init_with_args(&argc, &argv, "", option_entries, PACKAGE, &error)) 
@@ -186,15 +185,30 @@ int main(int argc,char **argv)
 		return EXIT_FAILURE;
 	}
 	
+	DBusConnection *connection;
+	DBusError derror;
+	
+	dbus_error_init(&derror);
+	
+	connection = dbus_bus_get(DBUS_BUS_SESSION, &derror);
+	
+	if ( dbus_error_is_set(&derror) )
+	{
+	    xfpm_popup_message(_("Xfce power manager"),
+                                  _("Unable to run Xfce4 power manager, " \
+                                  "make sure the hardware abstract layer and the message bus daemon "\
+                                  "are running"),
+                                  GTK_MESSAGE_ERROR);
+        g_error(_("Unable to load xfce4 power manager"));
+        g_print("\n");
+        dbus_error_free(&derror);        
+        return EXIT_FAILURE;        
+	}
+	
 	if ( config )
 	{
-		int reply;
-        if (!xfpm_dbus_send_message_with_reply("Running",&reply))
-        {
-            return EXIT_FAILURE;
-        }
-        if ( reply != 1 )
-        {
+	    if (!xfpm_dbus_name_has_owner(connection,XFPM_PM_IFACE))
+	    {
             g_print(_("Xfce power manager is not running"));
 			g_print("\n");
             gboolean ret = 
@@ -203,28 +217,35 @@ int main(int argc,char **argv)
                         _("Run"));
             if ( ret ) 
             {
-                g_spawn_command_line_async("xfce4-power-manager -r",NULL);
+                g_spawn_command_line_async("xfce4-power-manager",NULL);
             }
             return EXIT_SUCCESS;
-        }
-        xfpm_dbus_send_customize_message(socket_id);
-        return EXIT_SUCCESS;
-	}
-	
-	if ( run )
-	{
-		int reply;
-        if (!xfpm_dbus_send_message_with_reply("Running",&reply))
+	    }
+	    else
+	    {
+	        xfpm_dbus_send_customize_message(socket_id);
+	        return EXIT_SUCCESS;
+	    }
+	}     
+	 
+	if ( quit )
+    {
+        if (!xfpm_dbus_name_has_owner(connection,XFPM_PM_IFACE))
         {
-            return EXIT_FAILURE;
-        }
-        
-        if ( reply == 1 )
-        {
-            g_print(_("Xfce power manager is already running"));
+            g_print(_("Xfce power manager is not running"));
 			g_print("\n");
             return EXIT_SUCCESS;
         }
+        else
+        {
+            xfpm_dbus_send_message("Quit");
+            return EXIT_SUCCESS;
+        }
+    }    
+    
+    if (!xfpm_dbus_name_has_owner(connection,XFPM_PM_IFACE) )
+    {
+        dbus_connection_unref(connection);
         XfpmDriver *driver = xfpm_driver_new();
         autostart();
         if (!xfpm_driver_monitor(driver)) 
@@ -232,31 +253,20 @@ int main(int argc,char **argv)
             xfpm_popup_message(_("Xfce power manager"),
                               _("Unable to run Xfce4 power manager, " \
                               "make sure the hardware abstract layer and the message bus daemon "\
-							  "are running"),
+                              "are running"),
                               GTK_MESSAGE_ERROR);
             g_error(_("Unable to load xfce4 power manager"));
-			g_print("\n");
+            g_print("\n");
             g_object_unref(driver);
             return EXIT_FAILURE;
         }
-    }    
-    
-    if ( quit )
+    }
+    else
     {
-    	int reply;
-        if (!xfpm_dbus_send_message_with_reply("Quit",&reply))
-        {
-            return EXIT_FAILURE;
-        }
-        
-        if ( reply == 0 )
-        {
-            g_print(_("Xfce power manager is not running"));
-			g_print("\n");
-            return EXIT_SUCCESS;
-        }
+        g_print(_("Xfce power manager is already running"));
+        g_print("\n");
         return EXIT_SUCCESS;
-    }    
-    	
+    }
+	    
     return EXIT_SUCCESS;
 }    
